from distutils.core import setup

setup(
    name='LazarusLoot',
    version='0.1dev',
    packages=['src',],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('Readme.md').read(),
)
